@@ -1,5 +1,6 @@
 import contextlib
 import re
+import sys
 
 import click
 
@@ -18,14 +19,18 @@ def _term_len(x):
 
 class ProgressPrinter(contextlib.AbstractContextManager):
     def __init__(self, overwrite=True):
-        self.overwrite = overwrite
+        self.overwrite = overwrite and sys.stdout.isatty()
+        self.verbose = not overwrite
         self.last_width = 0
 
     def __enter__(self):
-        def printer(message):
+        def printer(message, force=False):
             if self.overwrite:
-                self._overwrite_previous_line(message)
-            else:
+                if force:
+                    click.echo(f"\n{message}")
+                else:
+                    self._overwrite_previous_line(message)
+            elif self.verbose:
                 click.echo(message)
 
         return printer
